#!/usr/bin/ruby
# encoding: utf-8

require 'retrieveDriveDetails'
require 'gtk2'
require 'vte'
require "rexml/document"

assi = Gtk::Assistant.new
drivelist = nil

#=============================================================================
# Function to build up the drive combo box
#=============================================================================


def update_drive_combo(combo, drives)
	partlist = Array.new
	999.downto(0) { |i|
		begin
			combo.remove_text(i)
		rescue
		end
	}
	parts_found = 0
	drives.drive_list.each { |k,v|
		if v.attached == "usb" 
			v.partitions.each { |id,inf|
				if inf.fs =~ /fat/ && inf.size > 2*1024^3 &&  inf.free_space > 1*1024^3
					# puts inf.id + " "+ inf.size.to_s + " " + inf.free_space.to_s 
					lab = ""
					lab = ", Label: " + inf.fslabel unless inf.fslabel.to_s == "" 
					combo.append_text(v.vendor + " " + v.model + " (" + (inf.size/1024/1024).to_s + "MB" + lab + ") " )
					partlist.push(inf.id)
				end
			}
		end
	}
	if partlist.size < 1 
		combo.append_text("Keine USB-Laufwerke gefunden. Bitte neu einlesen.")
		combo.sensitive = false
	else
		combo.sensitive = true
	end
	combo.active = 0
	return partlist 
end

#=============================================================================
# First page, tell the user what we need
#=============================================================================

desclabel = Gtk::Label.new
desclabel.set_markup("Es wird empfohlen, einen USB-Speicherstift als Zwischenspeicher anzustecken!\n\nDer Speicherstift wird mit einer (verschlüsselten) Auslagerungsdatei versehen und wird darüber hinaus Protokolldateien und aktualisierte Virensignaturen aufnehmen. Wenn Sie möchten, können Sie auch eine Installation auf USB-Speicherstift vornehmen, so können Sie die Notfall-CD auf Rechnern ohne optischem Laufwerk starten.\n\nBitte stecken Sie einen USB-Speicherstift an, auf dem wenigstens ein Gigabyte Platz frei ist und klicken Sie dann auf weiter. Auf Computern mit wenigstens einem Gigabyte Arbeitsspeicher können Sie ohne USB-Speicherstick fortfahren (nicht empfohlen). Klicken Sie in diesem Fall auf \"Abbrechen\".")
desclabel.wrap = true
desclabel.width_request = 550
desclabel.xalign = 0.1

descpage = assi.append_page(desclabel)
assi.set_page_title(desclabel, "USB-Speicherstift anschließen")
assi.set_page_type(desclabel, Gtk::Assistant::PAGE_CONTENT)
assi.set_page_complete(desclabel, true) # false)

#=============================================================================
# Second page, choose drive
#=============================================================================

drivebox = Gtk::VBox.new(true, 5)
drivelabel = Gtk::Label.new
drivelabel.set_markup("Bitte wählen Sie das Ziellaufwerk aus. Es werden nur USB-Laufwerke angezeigt, die wenigstens 2GB groß sind und über 1GB freien Speicher verfügen:")
drivelabel.wrap = true
drivelabel.width_request = 550
drivelabel.xalign = 0.1
drivecombo = Gtk::ComboBox.new
drivehbox = Gtk::HBox.new(false, 5)
drivebutton = Gtk::Button.new("Neu einlesen")
drivehbox.pack_start(drivecombo, true, true, 5)
drivehbox.pack_start(drivebutton, true, true, 5)
driveinst = Gtk::Label.new
driveinst.set_markup("Wollen Sie das ausgewählte Laufwerk startfähig formatieren? Dabei gehen alle dort gespeicherten Daten verloren. Falls sich wichtige Daten auf dem USB-Laufwerk befinden, verzichten Sie auf diese Option.")
driveinst.wrap = true
driveinst.width_request = 550
driveinst.xalign = 0.1
drivechck = Gtk::CheckButton.new("Ausgewähltes Laufwerk startfähig formatieren?")
drivebox.pack_start(drivelabel, true, false, 5)
drivebox.pack_start(drivehbox, true, false, 5)
drivebox.pack_start(driveinst, true, false, 5)
drivebox.pack_start(drivechck, true, false, 5)
drivepage = assi.append_page(drivebox)
assi.set_page_title(drivebox, "USB-Speicherstift auswählen")
assi.set_page_type(drivebox, Gtk::Assistant::PAGE_CONFIRM)
assi.set_page_complete(drivebox, true) # false)

#=============================================================================
# Build the assistent
#=============================================================================

assi.set_title  "USB-Zwischenspeicher"
assi.border_width = 10
assi.set_size_request(600, 410)
assi.signal_connect('destroy') { Gtk.main_quit }
assi.signal_connect('cancel')  { Gtk.main_quit }
assi.signal_connect('close') { 
	puts "Do something"
	# run USB installation
	# mount the disk
	# write the folder
	# make softlink?
	Gtk.main_quit
}

#=============================================================================
# Connect some callbacks
#=============================================================================

assi.set_forward_page_func{ |curr|
	# curr += 1
	if assi.current_page == 0 && drivelist.nil?
		puts "current screen 0, rereading drivelist"
		drivelist = AllDrives.new(true, false, false)
		update_drive_combo(drivecombo, drivelist)
		# drivelist.dump
	end
	curr = curr + 1
}

drivebutton.signal_connect("clicked") { 
	system("mdev -s")
	drivelist = AllDrives.new(true, false, false)
	update_drive_combo(drivecombo, drivelist)
}

#=============================================================================
# Show the assistent
#=============================================================================

assi.show_all
Gtk.main

